@@ -10,39 +10,37 @@ import pathlib
 import re
 import typing
 
-from typing import Any, DefaultDict, Dict, List, Mapping, Optional, OrderedDict, Tuple, Union
+from collections.abc import Mapping
+from typing import Any
 
 import packaging.markers
 import packaging.requirements
+import packaging.specifiers
 import packaging.version
 
 
-__version__ = '0.5.0'
+__version__ = '0.7.0'
 
 
 class ConfigurationError(Exception):
     '''Error in the backend metadata.'''
-    def __init__(self, msg: str, *, key: Optional[str] = None):
+    def __init__(self, msg: str, *, key: str | None = None):
         super().__init__(msg)
         self._key = key
 
     @property
-    def key(self) -> Optional[str]:  # pragma: no cover
+    def key(self) -> str | None:  # pragma: no cover
         return self._key
 
 
 class RFC822Message():
-    '''Simple RFC 822 message implementation.
-
-    Note: Does not support multiline fields, as Python packaging flavored
-    RFC 822 metadata does.
-    '''
+    '''Python-flavored RFC 822 message implementation.'''
 
     def __init__(self) -> None:
-        self.headers: OrderedDict[str, List[str]] = collections.OrderedDict()
-        self.body: Optional[str] = None
+        self.headers: collections.OrderedDict[str, list[str]] = collections.OrderedDict()
+        self.body: str | None = None
 
-    def __setitem__(self, name: str, value: Optional[str]) -> None:
+    def __setitem__(self, name: str, value: str | None) -> None:
         if not value:
             return
         if name not in self.headers:
@@ -53,7 +51,10 @@ class RFC822Message():
         text = ''
         for name, entries in self.headers.items():
             for entry in entries:
-                text += f'{name}: {entry}\n'
+                lines = entry.strip('\n').split('\n')
+                text += f'{name}: {lines[0]}\n'
+                for line in lines[1:]:
+                    text += ' ' * 8 + line + '\n'
         if self.body:
             text += '\n' + self.body
         return text
@@ -83,7 +84,7 @@ class DataFetcher():
             val = val[part]
         return val
 
-    def get_str(self, key: str) -> Optional[str]:
+    def get_str(self, key: str) -> str | None:
         try:
             val = self.get(key)
             if not isinstance(val, str):
@@ -96,7 +97,7 @@ class DataFetcher():
         except KeyError:
             return None
 
-    def get_list(self, key: str) -> List[str]:
+    def get_list(self, key: str) -> list[str]:
         try:
             val = self.get(key)
             if not isinstance(val, list):
@@ -116,7 +117,7 @@ class DataFetcher():
         except KeyError:
             return []
 
-    def get_dict(self, key: str) -> Dict[str, str]:
+    def get_dict(self, key: str) -> dict[str, str]:
         try:
             val = self.get(key)
             if not isinstance(val, dict):
@@ -136,7 +137,7 @@ class DataFetcher():
         except KeyError:
             return {}
 
-    def get_people(self, key: str) -> List[Tuple[str, str]]:
+    def get_people(self, key: str) -> list[tuple[str, str]]:
         try:
             val = self.get(key)
             if not (
@@ -163,34 +164,34 @@ class DataFetcher():
 
 class License(typing.NamedTuple):
     text: str
-    file: Optional[str]
+    file: pathlib.Path | None
 
 
 class Readme(typing.NamedTuple):
     text: str
-    file: Optional[str]
+    file: pathlib.Path | None
     content_type: str
 
 
 @dataclasses.dataclass
 class StandardMetadata():
     name: str
-    version: Optional[packaging.version.Version] = None
-    description: Optional[str] = None
-    license: Optional[License] = None
-    readme: Optional[Readme] = None
-    requires_python: Optional[packaging.specifiers.SpecifierSet] = None
-    dependencies: List[packaging.requirements.Requirement] = dataclasses.field(default_factory=list)
-    optional_dependencies: Dict[str, List[packaging.requirements.Requirement]] = dataclasses.field(default_factory=dict)
-    entrypoints: Dict[str, Dict[str, str]] = dataclasses.field(default_factory=dict)
-    authors: List[Tuple[str, str]] = dataclasses.field(default_factory=list)
-    maintainers: List[Tuple[str, str]] = dataclasses.field(default_factory=list)
-    urls: Dict[str, str] = dataclasses.field(default_factory=dict)
-    classifiers: List[str] = dataclasses.field(default_factory=list)
-    keywords: List[str] = dataclasses.field(default_factory=list)
-    scripts: Dict[str, str] = dataclasses.field(default_factory=dict)
-    gui_scripts: Dict[str, str] = dataclasses.field(default_factory=dict)
-    dynamic: List[str] = dataclasses.field(default_factory=list)
+    version: packaging.version.Version | None = None
+    description: str | None = None
+    license: License | None = None
+    readme: Readme | None = None
+    requires_python: packaging.specifiers.SpecifierSet | None = None
+    dependencies: list[packaging.requirements.Requirement] = dataclasses.field(default_factory=list)
+    optional_dependencies: dict[str, list[packaging.requirements.Requirement]] = dataclasses.field(default_factory=dict)
+    entrypoints: dict[str, dict[str, str]] = dataclasses.field(default_factory=dict)
+    authors: list[tuple[str, str]] = dataclasses.field(default_factory=list)
+    maintainers: list[tuple[str, str]] = dataclasses.field(default_factory=list)
+    urls: dict[str, str] = dataclasses.field(default_factory=dict)
+    classifiers: list[str] = dataclasses.field(default_factory=list)
+    keywords: list[str] = dataclasses.field(default_factory=list)
+    scripts: dict[str, str] = dataclasses.field(default_factory=dict)
+    gui_scripts: dict[str, str] = dataclasses.field(default_factory=dict)
+    dynamic: list[str] = dataclasses.field(default_factory=list)
 
     def __post_init__(self) -> None:
         self.name = re.sub(r'[-_.]+', '-', self.name).lower()
@@ -200,7 +201,7 @@ class StandardMetadata():
     def from_pyproject(
         cls,
         data: Mapping[str, Any],
-        project_dir: Union[str, os.PathLike[str]] = os.path.curdir,
+        project_dir: str | os.PathLike[str] = os.path.curdir,
     ) -> StandardMetadata:
         fetcher = DataFetcher(data)
         project_dir = pathlib.Path(project_dir)
@@ -280,7 +281,8 @@ class StandardMetadata():
         message['Author-Email'] = self._email_list(self.authors)
         message['Maintainer'] = self._name_list(self.maintainers)
         message['Maintainer-Email'] = self._email_list(self.maintainers)
-        # TODO: 'License'
+        if self.license:
+            message['License'] = self.license.text
         for classifier in self.classifiers:
             message['Classifier'] = classifier
         # skip 'Provides-Dist'
@@ -306,14 +308,14 @@ class StandardMetadata():
                 raise ConfigurationError(f'Field cannot be dynamic: {field}')
             message['Dynamic'] = field
 
-    def _name_list(self, people: List[Tuple[str, str]]) -> str:
+    def _name_list(self, people: list[tuple[str, str]]) -> str:
         return ', '.join(
             name
             for name, email_ in people
             if not email_
         )
 
-    def _email_list(self, people: List[Tuple[str, str]]) -> str:
+    def _email_list(self, people: list[tuple[str, str]]) -> str:
         return ', '.join([
             '{}{}'.format(name, f' <{_email}>' if _email else '')
             for name, _email in people
@@ -334,7 +336,7 @@ class StandardMetadata():
         return requirement
 
     @staticmethod
-    def _get_license(fetcher: DataFetcher, project_dir: pathlib.Path) -> Optional[License]:
+    def _get_license(fetcher: DataFetcher, project_dir: pathlib.Path) -> License | None:
         if 'project.license' not in fetcher:
             return None
 
@@ -346,47 +348,50 @@ class StandardMetadata():
                     key=f'project.license.{field}',
                 )
 
-        file = fetcher.get_str('project.license.file')
+        file: pathlib.Path | None = None
+        filename = fetcher.get_str('project.license.file')
         text = fetcher.get_str('project.license.text')
 
-        if (file and text) or (not file and not text):
+        if (filename and text) or (not filename and not text):
             raise ConfigurationError(
                 f'Invalid `project.license` value, expecting either `file` or `text` (got `{_license}`)',
                 key='project.license',
             )
 
-        if file:
-            if not os.path.isfile(file):
+        if filename:
+            file = project_dir.joinpath(filename)
+            if not file.is_file():
                 raise ConfigurationError(
-                    f'License file not found (`{file}`)',
+                    f'License file not found (`{filename}`)',
                     key='project.license.file',
                 )
-            text = project_dir.joinpath(file).read_text()
+            text = file.read_text(encoding='utf-8')
 
         assert text is not None
         return License(text, file)
 
     @staticmethod
-    def _get_readme(fetcher: DataFetcher, project_dir: pathlib.Path) -> Optional[Readme]:  # noqa: C901
+    def _get_readme(fetcher: DataFetcher, project_dir: pathlib.Path) -> Readme | None:  # noqa: C901
         if 'project.readme' not in fetcher:
             return None
 
-        file: Optional[str]
-        text: Optional[str]
-        content_type: Optional[str]
+        filename: str | None
+        file: pathlib.Path | None = None
+        text: str | None
+        content_type: str | None
 
         readme = fetcher.get('project.readme')
         if isinstance(readme, str):
             # readme is a file
             text = None
-            file = readme
-            if file.endswith('.md'):
+            filename = readme
+            if filename.endswith('.md'):
                 content_type = 'text/markdown'
-            elif file.endswith('.rst'):
+            elif filename.endswith('.rst'):
                 content_type = 'text/x-rst'
             else:
                 raise ConfigurationError(
-                    f'Could not infer content type for readme file `{file}`',
+                    f'Could not infer content type for readme file `{filename}`',
                     key='project.readme',
                 )
         elif isinstance(readme, dict):
@@ -398,9 +403,9 @@ class StandardMetadata():
                         key=f'project.readme.{field}',
                     )
             content_type = fetcher.get_str('project.readme.content-type')
-            file = fetcher.get_str('project.readme.file')
+            filename = fetcher.get_str('project.readme.file')
             text = fetcher.get_str('project.readme.text')
-            if (file and text) or (not file and not text):
+            if (filename and text) or (not filename and not text):
                 raise ConfigurationError(
                     f'Invalid `project.readme` value, expecting either `file` or `text` (got `{readme}`)',
                     key='project.license',
@@ -417,25 +422,26 @@ class StandardMetadata():
                 key='project.readme',
             )
 
-        if file:
-            if not os.path.isfile(file):
+        if filename:
+            file = project_dir.joinpath(filename)
+            if not file.is_file():
                 raise ConfigurationError(
-                    f'Readme file not found (`{file}`)',
+                    f'Readme file not found (`{filename}`)',
                     key='project.license.file',
                 )
-            text = project_dir.joinpath(file).read_text()
+            text = file.read_text(encoding='utf-8')
 
         assert text is not None
         return Readme(text, file, content_type)
 
     @staticmethod
-    def _get_dependencies(fetcher: DataFetcher) -> List[packaging.requirements.Requirement]:
+    def _get_dependencies(fetcher: DataFetcher) -> list[packaging.requirements.Requirement]:
         try:
             requirement_strings = fetcher.get_list('project.dependencies')
         except KeyError:
             return []
 
-        requirements: List[packaging.requirements.Requirement] = []
+        requirements: list[packaging.requirements.Requirement] = []
         for req in requirement_strings:
             try:
                 requirements.append(packaging.requirements.Requirement(req))
@@ -447,13 +453,13 @@ class StandardMetadata():
         return requirements
 
     @staticmethod
-    def _get_optional_dependencies(fetcher: DataFetcher) -> Dict[str, List[packaging.requirements.Requirement]]:
+    def _get_optional_dependencies(fetcher: DataFetcher) -> dict[str, list[packaging.requirements.Requirement]]:
         try:
             val = fetcher.get('project.optional-dependencies')
         except KeyError:
             return {}
 
-        requirements_dict: DefaultDict[str, List[packaging.requirements.Requirement]] = collections.defaultdict(list)
+        requirements_dict: collections.defaultdict[str, list[packaging.requirements.Requirement]] = collections.defaultdict(list)
         if not isinstance(val, dict):
             raise ConfigurationError(
                 'Field `project.optional-dependencies` has an invalid type, expecting a '
@@ -482,7 +488,7 @@ class StandardMetadata():
         return dict(requirements_dict)
 
     @staticmethod
-    def _get_entrypoints(fetcher: DataFetcher) -> Dict[str, Dict[str, str]]:
+    def _get_entrypoints(fetcher: DataFetcher) -> dict[str, dict[str, str]]:
         try:
             val = fetcher.get('project.entry-points')
         except KeyError:
